@@ -22,7 +22,7 @@ import (
 
 // Entrypoint - entrypoint script
 type Entrypoint struct {
-	input.Input
+	StaticInput
 }
 
 func (e *Entrypoint) GetInput() (input.Input, error) {
@@ -36,14 +36,5 @@ func (e *Entrypoint) GetInput() (input.Input, error) {
 
 const entrypointTmpl = `#!/bin/bash -e
 
-# This is documented here:
-# https://docs.openshift.com/container-platform/3.11/creating_images/guidelines.html#openshift-specific-guidelines
-
-if ! whoami &>/dev/null; then
-  if [ -w /etc/passwd ]; then
-    echo "${USER_NAME:-runner}:x:$(id -u):$(id -g):${USER_NAME:-runner} user:${HOME}:/sbin/nologin" >> /etc/passwd
-  fi
-fi
-
 exec ${OPERATOR} run ansible --watches-file=/opt/ansible/watches.yaml $@
 `
